# Learnings: How to use this file
Entries below are learnings or shortcut ideas created directly by the AI Coding Agents during their execution, to help future AI Coding Agents avoid error and optimize execution. 

- this file is modifed by AI
- appended entries should be kept short and concise
- never duplicate learnings; update previous entries if they were incomplete or obsolete

# Learnings
AI Coding Agents should append / update the bullet points below.

- The project source code directory is `src/`.
- Always use the "Standard Data Format" (SDF) when passing data between components.
- Append new learnings to this list first, then deduplicate before marking a Task as complete.
